@@ -58,7 +58,7 @@ class ColorDetectionConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    zone: Optional[List[List[int]]] = field(default_factory=lambda: None)
+    zone: Optional[List[List[int]]] = field(default_factory=lambda: [[69, 428], [886, 390], [1048, 712], [106, 712]])
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
                 0: "ambulance",
@@ -139,11 +139,12 @@ class ColorDetectionUseCase(BaseProcessor):
         self._track_merge_iou_threshold: float = 0.05  # IoU ≥ 0.05 →
         self._track_merge_time_window: float = 7.0  # seconds within which to merge
 
-        self._ascending_alert_list: List[int] = []
+        self._ascending_alert_list: List[int] = []  
         self.current_incident_end_timestamp: str = "N/A"
         self.color_det_dict = {}
         self.start_timer = None
-        self.zone = None
+        self.zone = self.zone = np.array([[69, 428], [886, 390], [1048, 712], [106, 712]], dtype=np.float32)
+        self.logger.info(f"Initialized zone with coordinates: {self.zone.tolist()}")
 
     def reset_tracker(self) -> None:
         """Reset the advanced tracker instance."""
@@ -179,7 +180,7 @@ class ColorDetectionUseCase(BaseProcessor):
             else:
                 return False
             cx = (x1 + x2) / 2
-            cy = (y1 + y2) / 4  # Modified from (y1 + y2) / 2 to (y1 + y2) / 4
+            cy = (y1 + 3*y2) / 4
             in_zone = cv2.pointPolygonTest(self.zone, (cx, cy), False) >= 0
             self.logger.debug(f"BBox point ({cx}, {cy}) in zone: {in_zone}")
             return in_zone
@@ -383,10 +384,10 @@ class ColorDetectionUseCase(BaseProcessor):
                 #     context=context
                 # )
 
-            # Initialize zone if provided
-            if config.zone and self.zone is None:
-                self.zone = np.array(config.zone, dtype=np.float32)
-                self.logger.info(f"Initialized zone with coordinates: {self.zone.tolist()}")
+            # # Initialize zone if provided
+            # if config.zone and self.zone is None:
+            #     self.zone = np.array(config.zone, dtype=np.float32)
+            #     self.logger.info(f"Initialized zone with coordinates: {self.zone.tolist()}")
             
             input_format = match_results_structure(data)
             context.input_format = input_format
