@@ -187,12 +187,17 @@ class VehicleMonitoringUseCase(BaseProcessor):
             category = detection.get("category", "unknown")
             counting_summary["categories"][category] = counting_summary["categories"].get(category, 0) + 1
         
+        print("---------------------PROCESSEDD-----------------------")
+        print(processed_data)
+        print("---------------------PROCESSEDD-----------------------")
         zone_analysis = {}
         if config.zone_config and config.zone_config['zones']:
             # Convert single frame to format expected by count_objects_in_zones
             frame_data = processed_data #[frame_detections]
             zone_analysis = count_objects_in_zones(frame_data, config.zone_config['zones'])
-            
+            print("-----------------------------ZONEEEE1-----------------------------------")
+            print(zone_analysis)
+            print("-----------------------------ZONEEEE1-----------------------------------")
             # Update zone tracking with current frame data
             if zone_analysis and config.enable_tracking:
                 enhanced_zone_analysis = self._update_zone_tracking(zone_analysis, processed_data, config)
@@ -303,7 +308,8 @@ class VehicleMonitoringUseCase(BaseProcessor):
             # Update counts
             self._zone_current_counts[zone_name] = len(current_tracks)
             self._zone_total_counts[zone_name] = len(self._zone_total_track_ids[zone_name])
-            
+            print(self._zone_current_counts)
+            print(self._zone_total_counts)
             # Create enhanced zone analysis
             enhanced_zone_analysis[zone_name] = {
                 "current_count": self._zone_current_counts[zone_name],
@@ -592,12 +598,12 @@ class VehicleMonitoringUseCase(BaseProcessor):
             for zone_name, zone_data in zone_analysis.items():
                 total_count = 0
                 if isinstance(zone_data, dict):
-                    if "total_count" in zone_data:
-                        total_count = zone_data.get("total_count", 0)
+                    if "total_track_ids" in zone_data:
+                        total_count = zone_data.get("total_track_ids", 0)
                     else:
-                        counts_dict = zone_data.get("original_counts") if isinstance(zone_data.get("original_counts"), dict) else zone_data
+                        counts_dict = zone_data.get("total_track_ids") if isinstance(zone_data.get("total_track_ids"), dict) else zone_data
                         total_count = counts_dict.get(
-                            "total",
+                            "total_track_ids",
                             sum(v for v in counts_dict.values() if isinstance(v, (int, float)))
                         )
                 human_text_lines.append(f"\t{zone_name}: {int(total_count)}")
